%define anolis_release 1
%global pypi_name faiss
%global pypi_version 1.8.0
%global vcu_maj 12
%global vcu_min 1 
Name:           faiss
Version:        %{pypi_version}
Release:        %{anolis_release}%{?dist}
Summary:        A library for efficient similarity search and clustering of dense vectors.

License:        MIT license
URL:            https://github.com/facebookresearch/faiss
Source0:        https://github.com/facebookresearch/faiss/archive/refs/tags/v1.8.0.tar.gz#/%{pypi_name}-%{pypi_version}.tar.gz

%define have_cuda 1
%define gpu_target_ptx "50"

%define gpu_target_bin 5.0;5.2;6.0;6.1;7.0;7.5;8.0;8.6;9.0


%if %{have_cuda}
BuildRequires:  cuda-nvcc-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvtx-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-cupti-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvprune-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-cudart-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvml-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvrtc-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-driver-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-profiler-api-%{vcu_maj}-%{vcu_min}
BuildRequires:  nvidia-driver-cuda-libs
BuildRequires:  libnpp-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcurand-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcusparse-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcublas-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcusolver-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcufft-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcurand-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libnvjpeg-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libnccl-devel
Requires:  cuda-cudart-%{vcu_maj}-%{vcu_min}
Requires:  cuda-nvrtc-%{vcu_maj}-%{vcu_min}
Requires:  cuda-nvtx-%{vcu_maj}-%{vcu_min}
%endif

BuildRequires:  python3-devel
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(numpy)
BuildRequires:  cmake gcc gcc-c++ swig lapack-devel blis-devel

%description
Faiss is a library for efficient similarity search and clustering of dense vectors. It contains algorithms that search 
in sets of vectors of any size, up to ones that possibly do not fit in RAM. It also contains supporting code for 
evaluation and parameter tuning. Faiss is written in C++ with complete wrappers for Python/numpy. Some of the most useful 
algorithms are implemented on the GPU. It is developed primarily at Meta's Fundamental AI Research group.

%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

Requires:       python3dist(numpy)
%description -n python3-%{pypi_name}
Faiss is a library for efficient similarity search and clustering of dense vectors. It contains algorithms that search 
in sets of vectors of any size, up to ones that possibly do not fit in RAM. It also contains supporting code for 
evaluation and parameter tuning. Faiss is written in C++ with complete wrappers for Python/numpy. Some of the most useful 
algorithms are implemented on the GPU. It is developed primarily at Meta's Fundamental AI Research group.

%package -n libfaiss
Summary:        %{summary}
%description -n libfaiss
Faiss is a library for efficient similarity search and clustering of dense vectors. It contains algorithms that search 
in sets of vectors of any size, up to ones that possibly do not fit in RAM. It also contains supporting code for 
evaluation and parameter tuning. Faiss is written in C++ with complete wrappers for Python/numpy. Some of the most useful 
algorithms are implemented on the GPU. It is developed primarily at Meta's Fundamental AI Research group.

%package -n libfaiss-devel
Summary:        development files for %{pypi_name}
%description -n libfaiss-devel
development files for %{pypi_name}

%prep
%autosetup -n %{pypi_name}-%{pypi_version}

%build
export CUDACXX=/usr/local/cuda/bin/nvcc
export CMAKE_CUDA_ARCHITECTURES='5.0;5.2;6.0;6.1;7.0;7.5;8.0;8.6;9.0'
%cmake -B build -DCMAKE_POSITION_INDEPENDENT_CODE=ON -DBUILD_TESTING=OFF
%make_build -C build faiss
%make_build -C build swigfaiss

%install
export CUDACXX=/usr/local/cuda/bin/nvcc
export CMAKE_CUDA_ARCHITECTURES='5.0;5.2;6.0;6.1;7.0;7.5;8.0;8.6;9.0'
cd build/faiss/python && %py3_install && cd ../../..
%make_install -C build 

%files -n libfaiss
%{_libdir}/libfaiss.so

%files -n libfaiss-devel
%{_includedir}/faiss/*
%{_datadir}/faiss/*

%files -n python3-%{pypi_name}
%license LICENSE
%doc README.md
%{python3_sitelib}/*

%changelog
* Fri Mar 08 2024 Zhongling He <zhonglingh@linux.alibaba.com> - 1.8.0-1
- Initial package.
